==> hpcli-0.9.tar.gz: hpcli-0.9/hpcli/hpclilib/common.py <==
import os
import json
from requests.compat import urljoin

DOCKER_REPO_URLS = {
    'python3-generic': 'dpbriggs/python3-generic',
}

MS_DEPLOY_URL_FRAGMENT = 'highlyprobable/microservice'
MS_URL_ROOT = "https://u2b27vbv1j.execute-api.us-east-1.amazonaws.com/prod/1/"

DRF_URL_ROOT = "https://backend.api.highlyprobable.com/"
if 'DEV' in os.environ:
    DRF_URL_ROOT = "http://localhost:8000/"

if 'MS_USE_LOCAL' in os.environ:
    MS_URL_ROOT = "http://localhost:8000/"

AUTH_URL_PATH = 'api/organizations/api-token-auth/'


MODULE_ROOT = os.path.dirname(os.path.abspath(__file__))
BIG_SEP = '=' * 80


def big_print(to_print, first_print=False):
    if first_print:
        print('')
    print(BIG_SEP)
    print('')
    print(to_print)
    print('')


def get_project_root(arguments):
    return os.path.join(os.getcwd(), arguments['<project-name>'])


def get_short_id(config):
    return config['id'][0:6]


def find_project_url_fragment(config, full_path=True):
    url = ""
    if 'id' in config and 'microservice-name' in config:
        if full_path:
            url = urljoin(MS_URL_ROOT, config['id'][0:6]) + '/'
            url = urljoin(url, config['microservice-name'])
        else:
            url = config['id'][0:6] + '/' + config['microservice-name']
    elif not url:
        raise ValueError('Cannot find a suitable url, did you start the project?')
    return url


def add_to_microservice_defn_file(project_root, to_add):
    microserice_defn_file = os.path.join(project_root, 'microservice-definition.json')
    if not os.path.exists(microserice_defn_file):
        return
    json_data = {}
    with open(microserice_defn_file, 'rb') as f:
        json_data = json.loads(f.read())
    json_data = {**json_data, **to_add}
    with open(microserice_defn_file, 'w') as f:
        f.write(json.dumps(json_data, indent=4, sort_keys=True))

==> hpcli-0.9.1.tar.gz: hpcli-0.9.1/hpcli/hpclilib/common.py <==
import os
import json
from requests.compat import urljoin

DOCKER_REPO_URLS = {
    'python3-generic': 'dpbriggs/python3-generic',
}

MS_DEPLOY_URL_FRAGMENT = 'highlyprobable/microservice'
MS_URL_ROOT = "https://u2b27vbv1j.execute-api.us-east-1.amazonaws.com/prod/1/"

DRF_URL_ROOT = "https://backend.api.highlyprobable.com/"
if 'DEV' in os.environ:
    DRF_URL_ROOT = "http://localhost:8000/"

if 'USE_LOCAL_DOCKER' in os.environ:
    MS_URL_ROOT = "http://localhost:8000/"

AUTH_URL_PATH = 'api/organizations/api-token-auth/'


MODULE_ROOT = os.path.dirname(os.path.abspath(__file__))
BIG_SEP = '=' * 80


def big_print(to_print, first_print=False):
    if first_print:
        print('')
    print(BIG_SEP)
    print('')
    print(to_print)
    print('')


def get_project_root(arguments):
    return os.path.join(os.getcwd(), arguments['<project-name>'])


def get_short_id(config):
    return config['id'][0:6]


def find_project_url_fragment(config, full_path=True):
    url = ""
    if 'id' in config and 'microservice-name' in config:
        if full_path:
            url = urljoin(MS_URL_ROOT, config['id'][0:6]) + '/'
            url = urljoin(url, config['microservice-name'])
        else:
            url = config['id'][0:6] + '/' + config['microservice-name']
    elif not url:
        raise ValueError('Cannot find a suitable url, did you start the project?')
    return url


def add_to_microservice_defn_file(project_root, to_add):
    microserice_defn_file = os.path.join(project_root, 'microservice-definition.json')
    if not os.path.exists(microserice_defn_file):
        return
    json_data = {}
    with open(microserice_defn_file, 'rb') as f:
        json_data = json.loads(f.read())
    json_data = {**json_data, **to_add}
    with open(microserice_defn_file, 'w') as f:
        f.write(json.dumps(json_data, indent=4, sort_keys=True))
